@@ -4,7 +4,7 @@ from rest_framework import status
 from rest_framework.test import APITestCase
 from djrest_wrapper.exceptions.apis import errors
 from ..models.user_models import User
-from ..models.profile_models import Profile
+from ..models import get_user_profile_model
 
 
 class UserViewSetTestCase(APITestCase):
@@ -26,6 +26,21 @@ class UserViewSetTestCase(APITestCase):
         self.assertIsNotNone(response.json().get(
             'data').get('user').get('access_token'))
 
+    def test_create_duplicate_user_view(self):
+        url = reverse('user-list')
+        data = {
+            'username': 'testuser',
+            'email': 'test@example.com',
+            'password': 'test'
+        }
+        User.objects.create(**data)
+        response = self.client.post(path=url, data=data, format='json')
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(response.json().get('err'), True)
+        self.assertEqual(response.json().get(
+            'err_code'), errors.ERR_DUPLICATE_MODEL)
+
+
     def test_signin_user_view(self):
         self.test_create_user_view()
         url = reverse('user-signin')
@@ -53,6 +68,10 @@ class UserViewSetTestCase(APITestCase):
         self.assertEqual(response.json().get(
             'err_code'), errors.ERR_SUCCESSFUL)
         self.assertIsNotNone(response.json().get('data').get('user'))
+        self.assertIsNotNone(response.json().get(
+            'data').get('user').get('profile'))
+        self.assertIsNotNone(response.json().get('data').get(
+            'user').get('profile').get('relprofile'))
 
     def test_retrieve_user_profile_view_failed(self):
         user = self.test_signin_user_view()
@@ -182,7 +201,7 @@ class UserViewSetTestCase(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
         try:
             deleting_user = User.objects.get(username=f'test')
-            deleting_user_profile = Profile.objects.get(user=user)
+            deleting_user_profile = get_user_profile_model().objects.get(user=user)
             self.assertIsNone(deleting_user)
             self.assertIsNone(deleting_user_profile)
         except User.DoesNotExist:
